"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_smart_logger_1 = require("ts-smart-logger");
var P = require("platform");
var util_1 = require("../util");
var definedLocation = typeof location === 'undefined'
    ? { origin: '', protocol: 'http', host: 'localhost', port: '80', href: '', pathname: '', assign: function (url) { return null; } }
    : location;
var definedWindow = typeof window === 'undefined' ? {} : window;
var definedDocument = typeof document === 'undefined' ? { baseURI: '', body: null } : document;
var definedLocalStorage = typeof localStorage === 'undefined' ? { getItem: function (item) { return null; } } : localStorage;
var origin = definedLocation.origin || [definedLocation.protocol, definedLocation.host].join('//');
var BASE_PATH = (definedDocument.baseURI || definedLocation.href).replace(origin, '');
var RN_PLATFORM_NAME = Reflect.get(definedWindow, '$$RAC-RN_PLATFORM_NAME');
var SAFARI_PLATFORM = P.name === 'Safari';
var IOS_PLATFORM = P.os.family === 'iOS';
exports.ENV = util_1.defValuesFilter({
    appVersion: process.env.APP_VERSION || '0.0.1',
    appProfile: process.env.APP_PROFILE || 'DEFAULT',
    appNamespace: process.env.APP_NAMESPACE,
    prodMode: process.env.NODE_ENV === 'production',
    devModeEnabled: !!definedLocalStorage.getItem('$$RAC-DEV_MODE'),
    googleKey: process.env.GOOGLE_KEY,
    googleMapsKey: process.env.GOOGLE_MAPS_KEY,
    rnPlatformName: RN_PLATFORM_NAME,
    rnPlatform: !!RN_PLATFORM_NAME,
    macPlatform: P.os.family === 'OS X',
    iosPlatform: IOS_PLATFORM,
    basePath: BASE_PATH,
    normalizedBasePath: BASE_PATH.replace(/\//g, ''),
    port: definedLocation.port || '80',
    platformName: P.name,
    platformOs: P.os,
    safariPlatform: SAFARI_PLATFORM,
    passwordInputPlaceholder: SAFARI_PLATFORM && IOS_PLATFORM ? '●' : '•',
    documentBody: definedDocument.body,
    appPath: function () { return util_1.buildNormalizedPath((definedLocation.pathname + "/").replace(BASE_PATH, '/')); },
    buildAppPath: function (path) { return util_1.buildNormalizedPath(BASE_PATH + "/" + path + "/"); },
});
ts_smart_logger_1.LoggerFactory.makeLogger('env.interface').debug('[$environment]', exports.ENV);
//# sourceMappingURL=env.interface.js.map